/*
 * Copyright © Microsoft Corporation. All rights reserved.
 */

// This file provides the interface between JavaScript in the WebView and the Java code in the Android app.
// For any method xyz that is called on this class, we attempt to call AndroidBridge.xyz.
// An exception is made in case the base class already implements a method.
// For those cases, we let the existing implementation run instead of forwarding.
// This is used in async methods, where the base class has the implementation of placeArrow (no forwarding), which in turn calls placeArrowAsync (with forwarding).
class AndroidPlatformCallbacks extends holographic.PlatformCallbacks {

  // No need to implement methods here. The proxy will forward everything that is not handled.

}

class AndroidForwarder {
  get(target, propertyName) {
    let propertyValue = target[propertyName];

    if (propertyValue !== undefined) {
      return propertyValue;
    }

    let bridgeValue = AndroidBridge[propertyName];

    if (bridgeValue === undefined) {
      return undefined;
    }

    return bridgeValue.bind(AndroidBridge);
  }
}

holographic.platform = new Proxy(new AndroidPlatformCallbacks(), new AndroidForwarder());
