package com.microsoft.trouterclient;

/**
 * This Java interface provides only a subset of the methods available on the underlying C++ object.
 */
public abstract class ITrouter {
    public static ITrouter create(long nativeTrouterPtr) {
        return new Trouter(nativeTrouterPtr);
    }

    /**
     * Registers a callback for receiving Trouter messages.
     * The callback provides a routing path which is used to direct matching server requests to this listener.
     * @return true if this callback was registered (even if this path has already been registered), false if
     *         the path contains invalid URL characters.
     */
    public abstract boolean registerListener(ITrouterListener listener, String path, String loggingName);

    /**
     * Unregisters a listener.
     * No further callbacks will occur on the listener after this method returns.
     * @return true if unregistered successfully, false if listener was already unregistered or on other error.
     */
    public abstract boolean unregisterListener(ITrouterListener listener);

    /**
     * Sets the user activity state on this endpoint/device
     *
     * The activity state will be sent to the service if it is different
     * from the previously sent state, upon reconnect, or under other
     * circumstances fully in the discretion of the client.
     */
    public abstract void setUserActivityState(UserActivityState state);
}
